package fr.eisti.ing1.java.teaching.data;
import org.example.teaching.data.Student;

public class EistiStudent extends Student implements Comparable<EistiStudent> {

	private static final long serialVersionUID = 777L;

	private int ranking;

	public EistiStudent(String firstname, String lastname, int age, 
			int ranking) 
	{
		super(firstname, lastname, age);
		this.ranking = ranking;
	}

	public EistiStudent(Student student) {
		this(student.getFirstName(), student.getLastName(), student.getAge(), 0);
	}

	// getters for firstName, lastName, age already exist by inheritance

	public int getRanking() {
		return this.ranking;
	}

	public void setRanking(int ranking) throws IllegalArgumentException {
		if (ranking < 0) {
			throw new IllegalArgumentException("ranking must be positive, here : " + ranking); 
		}
		this.ranking = ranking;
	}

	@Override
	public int compareTo(EistiStudent other) {
		int res;
		res = (new Integer(this.ranking)).compareTo(other.getRanking());
		if (res == 0) {
			res = this.getLastName().compareTo(other.getLastName());
			if (res == 0) {
				res = this.getFirstName().compareTo(other.getFirstName());
				if (res == 0) {
					res = (new Integer(this.getAge())).compareTo(other.getAge());
				}
			}
		}
		return res;
	}

	@Override
	public String toString() {
		return this.getLastName() + " " + this.getFirstName() + " ("
				+ this.getAge() + ") # " + this.getRanking();	
	}

	// warning : String equality is defined by equals operation, 
	// not by == operator
	@Override
	public boolean equals(Object o) {
		if ((o == null) || (!(o instanceof EistiStudent))) {
			return false;
		}
		EistiStudent os = (EistiStudent) o;
		return (this.getFirstName().equals(os.getFirstName())
				&& this.getLastName().equals(os.getLastName())
				&& this.getAge() == os.getAge()
				&& this.getRanking() == os.getRanking());
	}
}
